package main

import (
	"embed"
	"os"

	"github.com/duke-git/lancet/v2/fileutil"
	"github.com/wailsapp/wails/v2"
	"github.com/wailsapp/wails/v2/pkg/options"
	"github.com/wailsapp/wails/v2/pkg/options/assetserver"
)

//go:embed all:frontend/dist
var assets embed.FS

func main() {
	// Create an instance of the app structure
	app := NewApp()
	dir, err := os.UserHomeDir()
	if err != nil {
		return
	}
	if !fileutil.IsExist(dir + "/RDMWails") {
		fileutil.CreateDir(dir + "/RDMWails")
	}

	// Create application with options
	err = wails.Run(&options.App{
		Title:  "RDM-Wails",
		Width:  1024,
		Height: 768,
		AssetServer: &assetserver.Options{
			Assets: assets,
		},
		BackgroundColour: &options.RGBA{R: 27, G: 38, B: 54, A: 1},
		OnStartup:        app.startup,
		Bind: []interface{}{
			app,
		},
	})

	if err != nil {
		println("Error:", err.Error())
	}
}
